package com.ruoyi.mall.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mall.mapper.VipGuideMapper;
import com.ruoyi.mall.domain.VipGuide;
import com.ruoyi.mall.service.IVipGuideService;

/**
 * 会员指南Service业务层处理
 *
 * @author ruoyi
 * @date 2023-10-25
 */
@Service
public class VipGuideServiceImpl implements IVipGuideService
{
    @Autowired
    private VipGuideMapper vipGuideMapper;

    /**
     * 查询会员指南
     *
     * @param guideId 会员指南主键
     * @return 会员指南
     */
    @Override
    public VipGuide selectVipGuideByGuideId(Long guideId)
    {
        return vipGuideMapper.selectVipGuideByGuideId(guideId);
    }

    /**
     * 查询会员指南列表
     *
     * @param vipGuide 会员指南
     * @return 会员指南
     */
    @Override
    public List<VipGuide> selectVipGuideList(VipGuide vipGuide)
    {
        return vipGuideMapper.selectVipGuideList(vipGuide);
    }

    /**
     * 是否显示vip
     * @return
     */
    @Override
    public int selectVipShow() {
        return vipGuideMapper.selectVipShow();
    }

    /**
     * 新增会员指南
     *
     * @param vipGuide 会员指南
     * @return 结果
     */
    @Override
    public int insertVipGuide(VipGuide vipGuide)
    {
        vipGuide.setCreateTime(DateUtils.getNowDate());
        return vipGuideMapper.insertVipGuide(vipGuide);
    }

    /**
     * 修改会员指南
     *
     * @param vipGuide 会员指南
     * @return 结果
     */
    @Override
    public int updateVipGuide(VipGuide vipGuide)
    {
        vipGuide.setUpdateTime(DateUtils.getNowDate());
        return vipGuideMapper.updateVipGuide(vipGuide);
    }

    /**
     * 批量删除会员指南
     *
     * @param guideIds 需要删除的会员指南主键
     * @return 结果
     */
    @Override
    public int deleteVipGuideByGuideIds(Long[] guideIds)
    {
        return vipGuideMapper.deleteVipGuideByGuideIds(guideIds);
    }

    /**
     * 删除会员指南信息
     *
     * @param guideId 会员指南主键
     * @return 结果
     */
    @Override
    public int deleteVipGuideByGuideId(Long guideId)
    {
        return vipGuideMapper.deleteVipGuideByGuideId(guideId);
    }
}
